macholib.MachoGraph — Graph data structure of Mach-O dependencies — macholib v1.4.3 documentation

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »

# `macholib.MachoGraph` — Graph data structure of Mach-O dependencies

This module defines the class `MachOGraph` which represents the direct and indirect dependencies of one or more Mach-O files on other (library) files.

class `macholib.MachOGraph.` `MachOGraph`(...)

  To be discussed.

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »